==> haskell-refinery-0.4.0.0-213-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-refinery.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 refinery
version:              0.4.0.0
visibility:           public
id:                   refinery-0.4.0.0-2Pshin9cfVNIEYvJuRpEC6
key:                  refinery-0.4.0.0-2Pshin9cfVNIEYvJuRpEC6
license:              BSD-3-Clause
copyright:            2019 Reed Mullanix
maintainer:           reedmullanix@gmail.com
author:               Reed Mullanix
homepage:             https://github.com/totbwf/refinery#readme
synopsis:             Toolkit for building proof automation systems
description:
    Please see the README on GitHub at <https://github.com/githubuser/refinery#readme>

category:             Language
abi:                  9448fccf4c7dacfdce5d7df81e4e0e0e
exposed:              True
exposed-modules:
    Refinery.ProofState Refinery.Tactic Refinery.Tactic.Internal

hidden-modules:       Paths_refinery
import-dirs:          /usr/lib/ghc-9.4.8/site-local/refinery-0.4.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/refinery-0.4.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/refinery-0.4.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-refinery
hs-libraries:         HSrefinery-0.4.0.0-2Pshin9cfVNIEYvJuRpEC6
depends:
    base-4.17.2.1 exceptions-0.10.5 mmorph-1.2.0-3nIz0RIlBAUER45blfkK28
    mtl-2.2.2

haddock-interfaces:   /usr/share/doc/haskell-refinery/html/refinery.haddock
haddock-html:         /usr/share/doc/haskell-refinery/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-refinery-0.4.0.0-214-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-refinery.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 refinery
version:              0.4.0.0
visibility:           public
id:                   refinery-0.4.0.0-CTUc35N37KdGugsN5r0qlm
key:                  refinery-0.4.0.0-CTUc35N37KdGugsN5r0qlm
license:              BSD-3-Clause
copyright:            2019 Reed Mullanix
maintainer:           reedmullanix@gmail.com
author:               Reed Mullanix
homepage:             https://github.com/totbwf/refinery#readme
synopsis:             Toolkit for building proof automation systems
description:
    Please see the README on GitHub at <https://github.com/githubuser/refinery#readme>

category:             Language
abi:                  d8a427f03092bb9a112085ebcc7c3574
exposed:              True
exposed-modules:
    Refinery.ProofState Refinery.Tactic Refinery.Tactic.Internal

hidden-modules:       Paths_refinery
import-dirs:          /usr/lib/ghc-9.4.8/site-local/refinery-0.4.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/refinery-0.4.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/refinery-0.4.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-refinery
hs-libraries:         HSrefinery-0.4.0.0-CTUc35N37KdGugsN5r0qlm
depends:
    base-4.17.2.1 exceptions-0.10.5 mmorph-1.2.0-3nIz0RIlBAUER45blfkK28
    mtl-2.2.2

haddock-interfaces:   /usr/share/doc/haskell-refinery/html/refinery.haddock
haddock-html:         /usr/share/doc/haskell-refinery/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
